a5_threads: Set the number of threads used by a5R

a5_set_threadsR Documentation

Set the number of threads used by a5R

Description

Controls the number of threads used for parallel processing in vectorised functions. Set to 1 (the default) for sequential processing with zero overhead, or higher for parallel execution via rayon.

Usage

a5_set_threads(n = 1L)

a5_get_threads()

Arguments

n

Integer scalar. Number of threads. Must be >= 1.

Value

Invisibly returns the previous thread count.

Integer scalar.


a5R documentation built on March 26, 2026, 5:10 p.m.