| a5_cell_area | R Documentation |
Returns the area of a single cell in square metres at the given resolution(s). Because A5 is an equal-area DGGS, all cells at the same resolution have identical area.
a5_cell_area(resolution, units = "m^2")
resolution |
Integer vector of resolutions (0–30). |
units |
Character scalar specifying the output area unit (default
|
A units::units vector of areas.
a5_cell_area(0:5)
a5_cell_area(5, units = "km^2")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.