| a5_get_num_children | R Documentation |
Returns the number of child cells each parent cell contains when expanding from one resolution to another.
a5_get_num_children(parent_resolution, child_resolution)
parent_resolution |
Integer scalar (0–30). |
child_resolution |
Integer scalar (0–30), must be >=
|
A numeric scalar. Returned as double because the count can exceed R's integer range at large resolution deltas.
a5_get_num_cells(), a5_cell_to_children(),
a5_uncompact()
a5_get_num_children(5, 8) # 4^3 = 64
a5_get_num_children(0, 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.