| a5_set_threads | R Documentation |
Controls the number of threads used for parallel processing in vectorised functions. Set to 1 (the default) for sequential processing with zero overhead, or higher for parallel execution via rayon.
a5_set_threads(n = 1L)
a5_get_threads()
n |
Integer scalar. Number of threads. Must be >= 1. |
Invisibly returns the previous thread count.
Integer scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.